==> clutternomore-1.1.2%2B1.21.5-fabric-sources.jar: dev/tazer/clutternomore/common/mixin/recipe/ShapelessRecipeMixin.java <==
package dev.tazer.clutternomore.common.mixin.recipe;

import dev.tazer.clutternomore.common.shape_map.ShapeMap;
import net.minecraft.class_1867;
import net.minecraft.class_1937;
import net.minecraft.class_9694;
import net.minecraft.class_9695;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1867.class)
public class ShapelessRecipeMixin {
    //? >1.20.1 {
    @Inject(method = "matches(Lnet/minecraft/world/item/crafting/CraftingInput;Lnet/minecraft/world/level/Level;)Z", at=@At(value = "RETURN"), cancellable = true)
    private void noMatches(class_9694 input, class_1937 level, CallbackInfoReturnable<Boolean> cir) {
        if (ShapeMap.isShape(((ShapelessRecipeAccessor) (this)).getResult().method_7909())) {
            cir.setReturnValue(false);
        }
    }


    @Inject(method = "matches(Lnet/minecraft/world/item/crafting/RecipeInput;Lnet/minecraft/world/level/Level;)Z", at=@At(value = "RETURN"), cancellable = true)
    private void noMatches2(class_9695 input, class_1937 level, CallbackInfoReturnable<Boolean> cir) {
        if (ShapeMap.isShape(((ShapelessRecipeAccessor) (this)).getResult().method_7909())) {
            cir.setReturnValue(false);
        }
    }
    //?} else {
    /*@Inject(method = "matches(Lnet/minecraft/world/inventory/CraftingContainer;Lnet/minecraft/world/level/Level;)Z", at = @At("RETURN"), cancellable = true)
    private void noMatches(CraftingContainer inv, Level level, CallbackInfoReturnable<Boolean> cir) {
        if (ShapeMap.isShape(((ShapelessRecipeAccessor) (this)).getResult().getItem())) {
            cir.setReturnValue(false);
        }
    }

    @Inject(method = "matches(Lnet/minecraft/world/Container;Lnet/minecraft/world/level/Level;)Z", at = @At("RETURN"), cancellable = true)
    private void noMatches2(Container par1, Level par2, CallbackInfoReturnable<Boolean> cir) {
        if (ShapeMap.isShape(((ShapelessRecipeAccessor) (this)).getResult().getItem())) {
            cir.setReturnValue(false);
        }
    }
    *///?}
}

==> clutternomore-1.1.4%2B1.21.8-fabric-sources.jar: dev/tazer/clutternomore/common/mixin/recipe/ShapelessRecipeMixin.java <==
package dev.tazer.clutternomore.common.mixin.recipe;

import dev.tazer.clutternomore.common.shape_map.ShapeMap;
import net.minecraft.class_1867;
import net.minecraft.class_1937;
import net.minecraft.class_9694;
import net.minecraft.class_9695;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1867.class)
public class ShapelessRecipeMixin {
    //? >1.20.1 {
    @Inject(method = "matches(Lnet/minecraft/world/item/crafting/CraftingInput;Lnet/minecraft/world/level/Level;)Z", at=@At(value = "RETURN"), cancellable = true)
    private void noMatches(class_9694 input, class_1937 level, CallbackInfoReturnable<Boolean> cir) {
        if (ShapeMap.isShape(((ShapelessRecipeAccessor) (this)).getResult().method_7909())) {
            cir.setReturnValue(false);
        }
    }


    @Inject(method = "matches(Lnet/minecraft/world/item/crafting/RecipeInput;Lnet/minecraft/world/level/Level;)Z", at=@At(value = "RETURN"), cancellable = true)
    private void noMatches2(class_9695 input, class_1937 level, CallbackInfoReturnable<Boolean> cir) {
        if (ShapeMap.isShape(((ShapelessRecipeAccessor) (this)).getResult().method_7909())) {
            cir.setReturnValue(false);
        }
    }
    //?} else {
    /*@Inject(method = "matches(Lnet/minecraft/world/inventory/CraftingContainer;Lnet/minecraft/world/level/Level;)Z", at = @At("RETURN"), cancellable = true)
    private void noMatches(CraftingContainer inv, Level level, CallbackInfoReturnable<Boolean> cir) {
        if (ShapeMap.isShape(((ShapelessRecipeAccessor) (this)).getResult().getItem())) {
            cir.setReturnValue(false);
        }
    }

    @Inject(method = "matches(Lnet/minecraft/world/Container;Lnet/minecraft/world/level/Level;)Z", at = @At("RETURN"), cancellable = true)
    private void noMatches2(Container par1, Level par2, CallbackInfoReturnable<Boolean> cir) {
        if (ShapeMap.isShape(((ShapelessRecipeAccessor) (this)).getResult().getItem())) {
            cir.setReturnValue(false);
        }
    }
    @Inject(method = "getResultItem", at = @At("RETURN"), cancellable = true)
    private void noResult(RegistryAccess registryAccess, CallbackInfoReturnable<ItemStack> cir) {
        if (ShapeMap.isShape(cir.getReturnValue().getItem())) {
            cir.setReturnValue(ItemStack.EMPTY);
        }
    }
    *///?}

    //? if =1.21.1 {
    /*@Inject(method = "getResultItem", at = @At("RETURN"), cancellable = true)
    private void noResult(HolderLookup.Provider registries, CallbackInfoReturnable<ItemStack> cir) {
        if (ShapeMap.isShape(cir.getReturnValue().getItem())) {
            cir.setReturnValue(ItemStack.EMPTY);
        }
    }
    *///?}
}
